<?php namespace WeCodeArt\Core;
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit();
// Use
use WeCodeArt\Utilities\Markup\SVG;
use WeCodeArt\Walkers\Comment as CommentWalker;
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Comments Class
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		v3.5
 * @version		v3.5
 */
class Comments {
	/**
	 * Instance
	 *
	 * @var $_instance
	 */
	private static $_instance = NULL;

	/**
	 * Initiator
	 *
	 * @since 	v3.5
	 * @return 	object
	 */
	public static function get_instance() {
		if( self::$_instance == NULL ) self::$_instance = new self;
		return self::$_instance;
	}

	/**
	 * Class Constructor.
	 */
	public function __construct() {
		// WP Core
		add_filter( 'comment_form_fields',	[ $this, 'comment_form_fields' 		] );
		add_filter( 'comment_reply_link',	[ $this, 'replace_reply_link_class' ] );
		// WeCodeArt Core
		add_action( 'wecodeart_comments_list', 	[ $this, 'render_comments_list' ] );
		add_action( 'wecodeart_pings_list', 	[ $this, 'render_pings_list' 	] );
		add_action( 'wecodeart_comment_form', 	[ $this, 'render_comment_form' 	] );
		add_action( 'wecodeart_entry_footer', 	[ $this, 'get_comments_template' ], 50 );
	}
	
	/**
	 * Get the comments template
	 * @since 	unknown
	 * @version	3.5
	 * @return 	HTML 
	 */
	public function get_comments_template() {
		// Bail if post does not support Comments
		if ( ! post_type_supports( get_post_type(), 'comments' ) ) return;
		// Run on singular pages
		if ( is_singular() && ! in_array( get_post_type(), array( 'post', 'page' ) ) ) {
			comments_template( '', true );
		} elseif ( is_singular( 'post' ) ) {
			comments_template( '', true );
		} elseif ( is_singular( 'page' ) ) {
			comments_template( '', true );
		}
	}

	/**
	 * Render Comments List
	 * @since	unknows
	 * @version v3.6
	 * @return 	string HTML
	 */
	public function render_comments_list() {
		$comments_number = get_comments_number();
		if ( have_comments() ) {
			$icon = SVG::compile( 'icon--comments' ); 
			echo '<h3 id="comments-title" class="comments__headline">' . $icon . ' ';
			if ( 1 === $comments_number ) {
				printf( _x( 'One comment', 'comments title', 'wecodeart' ) );
			} else {
				printf(
					_nx(
						'%1$s comment',
						'%1$s comments',
						$comments_number,
						'comments title',
						'wecodeart'
					),
					number_format_i18n( $comments_number )
				);
			}
			
			if ( comments_open() ) echo '<a class="float-right" href="#respond" rel="nofollow">' . __( 'add one', 'wecodeart' ) . '</a>';
			
			echo '</h3>';
			
			$args = apply_filters( 'wecodeart/filter/comments/list/args', array(
				'type' 			=> 'comment',
				'avatar_size' 	=> 60,
				'walker'		=> new CommentWalker,
			) );
			echo '<ol id="comments-list" class="comments-list unstyled pl-0">';
			wp_list_comments( $args );
			echo '</ol>';
			// Comments Navigation
			$prev_link = get_previous_comments_link();
			$next_link = get_next_comments_link();
			if ( $prev_link || $next_link ) {
				echo '<nav class="comments-navigation"><div class="row">';
				echo '<h3 class="show-for-sr">' . __( 'Comments Navigation', 'wecodeart' ) . '</h3>';
				if ( $prev_link ) printf( '<div class="col col-sm-12 col-md">%s</div>', $prev_link );
				if ( $next_link ) printf( '<div class="col col-sm-12 col-md text-right">%s</div>', $next_link );			
				echo '</div></nav>';
			}
		// If Comments are open but there are no comments, print this message!
		} elseif ( comments_open() && 
			$comments_empty_text = sprintf( 
				__( 'No comments, so go and ... %s', 'wecodeart' ), 
				'<a class="float-right" href="#respond" rel="nofollow">add one</a>' 
				) ) {
			echo '<h3 id="comments-title" class="headline">' . SVG::compile( 'icon--comments' ) . ' ' . $comments_empty_text . '</h3>';
		}
	}

	/**
	 * Render Comment Form.
 	 * @since	unknown
	 * @version v3.6
	 */
	public function render_comment_form() {
		// Bail if comments are closed for this post type.
		if ( ( is_singular() && ! comments_open() ) ) return;
	
		$args = apply_filters( 'wecodeart/filter/comments/form/args', array(
			'format'			 	=> 'html5',
			'title_reply_before' 	=> '<h3 id="reply-title" class="headline"> ' . SVG::compile( 'icon--comment-dots' ) . ' ',
			'title_reply_after'  	=> '</h3>',
			'class_form' 			=> 'comment-form row no-gutters',
			'class_submit' 			=> 'btn btn-primary',
			'cancel_reply_before' 	=> '<span class="float-right"><small>',
			'cancel_reply_after' 	=> '</small></span>'
		) );

		comment_form( $args );
	}

	/**
	 * Render Pings List.
	 * @since	unknown
	 * @version v3.5
	 */
	public function render_pings_list() {
		global $wp_query;
		
		// If have pings.
		if ( ! empty( $wp_query->comments_by_type['pings'] ) ) {
			$args = apply_filters( 'wecodeart/filter/pings/args', array(
				'type' 		 => 'pings',
				'short_ping' => true,
				'walker'	 => new CommentWalker,
			) );
			echo '<ol id="pings-list" class="pings-list no-bullet">';
			wp_list_comments( $args );
			echo '</ol>';
		}
	}

	/**
	 * Move Comment Field Bellow Name/Email/Website.
	 * @since	unknown
	 * @version v3.5
	 * @param 	array $fields
	 * @return 	array $fields
	 */
	public function comment_form_fields( $fields ) {
		$comment_field = $fields['comment'];
		unset( $fields['comment'] );
		
		$fields['comment'] = $comment_field;
		return $fields;
	}

	/**
	 * Replace Comment Reply Button class.
	 * @since	unknown
	 * @version v3.6
	 * @param 	string $class
	 * @return 	string $class
	 */
	public function replace_reply_link_class( $class ) {
		$class = str_replace( "class='comment-reply-link", "class='comment-reply-link btn btn-primary btn-sm", $class );
		return $class;
	}
}