<?php namespace WeCodeArt\Core;
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit();
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Pagination Class
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since 		v3.5
 * @version		v3.6
 */

class Pagination {
	/**
	 * Instance
	 *
	 * @var $_instance
	 */
	private static $_instance = NULL;

	/**
	 * Initiator
	 *
	 * @since 	v3.5
	 * @return 	object
	 */
	public static function get_instance() {
		if( self::$_instance == NULL ) self::$_instance = new self;
		return self::$_instance;
	}

	/**
	 * Class Constructor.
	 */
	public function __construct() {
        add_action( 'wecodeart/hook/main/after',    [ $this, 'numeric_posts_nav' ], 10 );
        add_action( 'wecodeart_entry_footer',       [ $this, 'post_content_nav' ],  10 );
        add_action( 'wecodeart_entry_footer',       [ $this, 'prev_next_post_nav' ], 90 );
        add_filter( 'wecodeart/filter/entry/prev_next_nav/enabled', [ $this, 'filter_prev_next_page' ], 10, 2 );
	}
	
	/**
	 * Display links to previous and next post, from a single post.
	 * @since	v1.0
	 * @version	v3.6.0.6
     * @return  null        Return early if not a post.
	 */
	public function prev_next_post_nav() {
        // Return only on Single Post
        $single_post_navigation_enabled = apply_filters( 'wecodeart/filter/entry/prev_next_nav/enabled', true, get_post_type() );
        
        if ( ! is_singular() || $single_post_navigation_enabled === false ) return;	

        $post_obj = get_post_type_object( get_post_type() );

        // Set the defaults
        $prev = '<span class="screen-reader-text">' . sprintf( 
            __( 'Previous %s', 'wecodeart' ),
            $post_obj->labels->singular_name
        ) . '</span>';

        $next = '<span class="screen-reader-text">' . sprintf( 
            __( 'Next %s', 'wecodeart' ),
            $post_obj->labels->singular_name
        ) . '</span>';

        $schema = '<span itemprop="name">%title</span>';
        
        // The HTML
        ?>
        <nav id="entry-prev-next" class="entry-prev-next"
            itemscope="" itemtype="http://schema.org/SiteNavigationElement">
            <h3 class="screen-reader-text"><?php 
                echo sprintf( __( '%s Navigation', 'wecodeart' ), $post_obj->labels->singular_name ); 
            ?></h3>
            <div class="row pt-3">
            <?php
                previous_post_link(
                    '<div class="col col-sm-12 col-md">' . $prev . '%link</div>', 
                    '&#x000AB; '. $schema 
                );
                next_post_link(
                    '<div class="col col-sm-12 col-md text-md-right">' . $next . '%link</div>',  
                    $schema .' &#x000BB;'
                );
            ?>
            </div>
        </nav>
    <?php
    }

	/**
     * Display links to previous and next post, from a single post.
     * @since	v1.0
     * @version v3.6
     * @return  string HTML
     */
    public function numeric_posts_nav() {
        $args = array( 
            'mixed' => 'array',
            'type' 	=> 'array',
        );
        
        $links = paginate_links( $args );
        
        if ( empty( $links ) || is_singular() ) return; 	
        
        ?>	
        <nav itemscope="" itemtype="http://schema.org/SiteNavigationElement">
            <ul class="pagination" role="navigation" aria-label="<?php esc_attr_e( 'Pagination', 'wecodeart' ); ?>">
                <?php foreach( $links as $key => $link ) { 
                        $class = [ 'page-item', 'pagination__item' ];
                        $class[] = ( strpos( $link, 'current' ) !== false ) ? 'pagination__item--current' : NULL;
                        $class[] = ( strpos( $link, 'current' ) !== false ) ? 'active' : NULL;
                        $class = array_map( 'sanitize_html_class', $class );
                    ?>
                    <li class="<?php echo esc_attr( trim( implode( ' ', $class ) ) ); ?>">
                        <?php echo str_replace( 'page-numbers', 'page-link', $link ); ?>
                    </li> 				
                <?php } ?>
            </ul>
        </nav>
        <?php
    }

    /**
     * WP-Link Pages for paginated posts
     * @since	unknown
     * @version v3.6.0
     * @return 	null 	Return early if not a post.
     */
    public function post_content_nav() {
        // Return only on Single Post
        if ( ! is_singular( 'post' ) ) return;	
        
        $label = '<span class="entry-pages__title label">' . __( 'Pages:', 'wecodeart' ) . '</span>';
        wp_link_pages( array(
            'before'      => '<nav class="entry-pages pagination" itemscope="" itemtype="http://schema.org/SiteNavigationElement">' . $label,
            'after'       => '</nav>',
            'link_before' => '<span class="page-link">',
            'link_after'  => '</span>',
        ) );
    }

    /**
     * Filter to disable prev/next nav on pages
     * @since 3.6.0.6
     * @param   boolean     $enabled
     * @param   string      $post_type
     * @return  boolean
     */
    public function filter_prev_next_page( $enabled, $post_type ) {
        if( $post_type === 'page' ) $enabled = false;
        return $enabled;
    }
}